Django Pydenticon
=================

Django Pydenticon is a Django application that provides an identicon
generator. The implementation uses Pydenticon library for generating the
identicons:

* https://github.com/azaghal/pydenticon/
* https://projects.majic.rs/pydenticon

Django Pydenticon comes with some pre-defined sane defaults for generating the
identicons, but is configurable, letting the user generate identicons with
custom parameters. Some parameters can be even overridden on case-by-case basis.

License
=======

Django Pydenticon is released under terms of *BSD (3-Clause) License*. See the
*LICENSE* file for more details.
